@@ -1,8 +1,8 @@
-matchit2full <- function(treat, X, data, distance, discarded,
+matchit2full <- function(treat, X, data, distance, discarded, is.full.mahalanobis,
                          verbose=FALSE, ...) { 
-  if (!("optmatch" %in% .packages(all = TRUE)))
-    install.packages("optmatch")
-  require(optmatch)
+
+  if (!requireNamespace("optmatch", quietly = TRUE)) 
+      stop("optmatch package is required.  Please install it.")
   
   if(verbose)
     cat("Full matching... \n")
@@ -19,7 +19,7 @@ matchit2full <- function(treat, X, data, distance, discarded,
   colnames(d) <- names(ttt[ttt==0])
   for (i in 1:n1) 
     d[i,] <- abs(d1[i]-d0)
-  full <- fullmatch(d, ...)
+  full <- optmatch::fullmatch(d, ...)
   psclass <- full[pmatch(names(ttt), names(full))]
   psclass <- as.numeric(as.factor(psclass))
   names(psclass) <- names(ttt)
