@@ -4,21 +4,23 @@
 
 ## load the Lalonde data
 data(lalonde)
-user.prompt()
 
 ## conduct full matching using the propensity score based on logistic regression
 m.out <- matchit(treat ~ age + educ + black + hispan + married +
                  nodegree + re74 + re75, data = lalonde,
                  method = "full", distance = "logit")
-user.prompt()
 
 ## print a short summary
 print(m.out)
 user.prompt()
 
 ## balance diagnostics through statistics
-summary(m.out)
+s.out <- summary(m.out)
+print(s.out)
+s.out <- summary(m.out, standardize=TRUE)
+print(s.out)
 user.prompt()
 
 ## balance diagnostics through graphics
 plot(m.out)
+plot(s.out)
